@@ -83,12 +83,12 @@ if __name__ == "__main__":
                                                 do_entropies=do_ent)
         df_mini_scree_plots = nmf.collect_windows_from_scree_plot(df_collected_windows=df_mini_scree_plots,
                                                                   df_scree_plot=df_scree_plot, known_ncomp=nb_clusters,
-                                                                  ncomp_margin=1)
+                                                                  ncomp_margin=5)
 
         if itrial % writefreq == 0 or itrial == nruns-1:
             print(f"Saving iteration {itrial} in {outputpath}")
             # assert not df_mini_scree_plots.empty
             outputpath.write(df_mini_scree_plots)
-            df_scree_plot.to_csv(args.output.split(".csv")[0]+f"_scp{itrial}_nc{nb_clusters}.csv")
+            # df_scree_plot.to_csv(args.output.split(".csv")[0]+f"_scp{itrial}_nc{nb_clusters}.csv")
             assert outputpath.isfile()
             assert not outputpath.read().empty
