@@ -1,6 +1,9 @@
 import socket
 from pathlib import Path
 import os
+import dotenv
+
+dotenv.load_dotenv()
 
 
 def get_root_path():
@@ -21,7 +24,7 @@ def get_root_path():
             rootpath = (Path(r"/home/cgeissler/local_data") if under_ubuntu
                         else Path(r"C:/Users/Christophe Geissler/"))
         else:
-            rootpath = Path(r"/media/SERVEUR/production/research_and_development/") if under_ubuntu else \
+            rootpath = Path(r"/media/SERVEUR/production/") if under_ubuntu else \
                        Path(r"/davs://advestis.synology.me:5006/")
     elif host == "cgeissler-portable":
         # Session laptop sous WIndows
